#' Pattern Matching and Extraction
#' 
#' Function to extract a certain index from \code{gregexpr()}.
#' 
#' See \code{?gregexpr} for further information on arguments.
#' See \code{?"regular expression"} for the use of regular expressions.
#' 
#' @param pattern Character string containing a regular expression to be searched in \code{text}.
#' @param text Character vector where the search is performed.
#' @param n Numeric value or character string \code{"last"} to 
#' extract \code{n}th or last position of \code{pattern} in each value of \code{text}.
#' @param ... Arguments passed to function \code{gregexpr()}.
#' @return
#' Numeric vector of length \code{length(text)}.
#' @seealso
#' \link{gregexpr}, regular expression (\link{regex})
#' @examples
#' #
#' 
#' gregexprind(c("a"),c("abab","ab","xyz",NA), 1)
#' gregexprind(c("a"),c("abab","ab","xyz",NA), 2)
#' gregexprind(c("a"),c("abab","ab","xyz",NA), "last")
#' 
#' #
#' @name gregexprind
#' @keywords gregexpr index regular expression
#' @author Sven E. Templer (\email{sven.templer@@gmail.com})

#' @export gregexprind
gregexprind <- function(pattern, text, n, ...) {
  x <- gregexpr(pattern, text, ...)
  if (is.numeric(n)) {
    x <- unlist(lapply(x, function(y) unlist(y)[n]))
  }
  if (n == "last") {
    x <- unlist(lapply(x, function(y) tail(unlist(y),1)))
  }
  x[x < 0] <- NA
  return(x)
}
